@@ -95,9 +95,10 @@ def has_equal_ast(incorrect_msg=None,
 
     Args:
         incorrect_msg: message displayed when ASTs mismatch. When you specify ``code`` yourself, you have to specify this.
-        code: optional code to use instead of the solution AST
+        code: optional code to use instead of the solution AST.
         exact: whether the representations must match exactly. If false, the solution AST
                only needs to be contained within the student AST (similar to using test student typed).
+               Defaults to ``True``, unless the ``code`` argument has been specified.
 
     :Example:
 
@@ -154,7 +155,7 @@ def has_equal_ast(incorrect_msg=None,
 
     _msg = state.build_message(incorrect_msg, fmt_kwargs, append=append)
 
-    if exact:
+    if exact and not code:
         rep.do_test(EqualTest(stu_rep, sol_rep, Feedback(_msg, state)))
     elif not sol_rep in stu_rep:
         rep.do_test(Test(Feedback(_msg, state)))
@@ -192,18 +193,17 @@ def has_expr(incorrect_msg=None,
     rep = Reporter.active_reporter
 
     get_func = partial(evalCalls[test], 
-                       extra_env = extra_env,
-                       context_vals = context_vals,
-                       pre_code = pre_code,
-                       expr_code = expr_code,
-                       name = name,
-                       copy=copy,
-                       do_exec = True if test == 'output' else False)
+                       extra_env=extra_env,
+                       context_vals=context_vals,
+                       pre_code=pre_code,
+                       expr_code=expr_code,
+                       name=name,
+                       copy=copy)
 
-    eval_sol, str_sol = get_func(tree = state.solution_tree,
-                                 process = state.solution_process,
-                                 context = state.solution_context,
-                                 env = state.solution_env)
+    eval_sol, str_sol = get_func(tree=state.solution_tree,
+                                 process=state.solution_process,
+                                 context=state.solution_context,
+                                 env=state.solution_env)
 
     if (test == 'error') ^ isinstance(eval_sol, Exception):
         raise ValueError("Evaluating expression raised error in solution process (or not an error if testing for one). "
@@ -211,10 +211,10 @@ def has_expr(incorrect_msg=None,
     if isinstance(eval_sol, ReprFail):
         raise ValueError("Couldn't figure out the value of a default argument: " + eval_sol.info)
 
-    eval_stu, str_stu = get_func(tree = state.student_tree,
-                                 process = state.student_process,
-                                 context = state.student_context,
-                                 env = state.student_env)
+    eval_stu, str_stu = get_func(tree=state.student_tree,
+                                 process=state.student_process,
+                                 context=state.student_context,
+                                 env=state.student_env)
 
     # kwargs ---
     fmt_kwargs = {
@@ -223,8 +223,14 @@ def has_expr(incorrect_msg=None,
         'name': name, 'test': test,
         'test_desc': '' if test == 'value' else 'the %s ' % test
     }
+
     fmt_kwargs['stu_eval'] = utils.shorten_str(str(eval_stu))
     fmt_kwargs['sol_eval'] = utils.shorten_str(str(eval_sol))
+    if incorrect_msg == DEFAULT_INCORRECT_MSG and \
+        ( fmt_kwargs['stu_eval'] is None or
+          fmt_kwargs['sol_eval'] is None or
+          fmt_kwargs['stu_eval'] == fmt_kwargs['sol_eval'] ):
+        incorrect_msg = "Expected something different."
 
     # tests ---
     # error in process
@@ -368,18 +374,15 @@ def has_code(text,
 from pythonwhat.Test import Test, DefinedCollTest, EqualTest
 
 def has_import(name,
-               same_as=True,
+               same_as=False,
                not_imported_msg="__JINJA__:Did you import `{{pkg}}`?",
                incorrect_as_msg="__JINJA__:Did you import `{{pkg}}` as `{{alias}}`?",
                state=None):
-    """Check whether code has certain import statement.
-
-    Test whether an import statement is used the same in the student's environment as in the solution
-    environment.
+    """Checks whether student imported a package or function correctly.
 
     Args:
         name (str): the name of the package that has to be checked.
-        same_as (bool): if false, the alias of the package doesn't have to be the same. Defaults to True.
+        same_as (bool): if True, the alias of the package or function has to be the same. Defaults to False.
         not_imported_msg (str): feedback message when the package is not imported.
         incorrect_as_msg (str): feedback message if the alias is wrong.
 
@@ -399,8 +402,8 @@ def has_import(name,
         SCT::
 
             Ex().has_import("numpy")  # pass
-            Ex().has_import("pandas") # fail
-            Ex().has_import("pandas", same_as = False) # pass
+            Ex().has_import("pandas") # pass
+            Ex().has_import("pandas", same_as=True) # fail
 
     """
 
